@@ -4,6 +4,7 @@ import time
 from stream.exceptions import ApiKeyException, InputException
 import random
 import jwt
+import pytz
 
 try:
     from unittest.case import TestCase
@@ -831,7 +832,7 @@ class ClientTest(TestCase):
         b.) The same time and foreign id
         """
 
-        utcnow = datetime.datetime.utcnow()
+        utcnow = datetime.datetime.now(tz=pytz.utc)
         activity_data = {"actor": 1, "verb": "tweet", "object": 1, "time": utcnow}
         self.user1.add_activity(activity_data)
         self.user1.add_activity(activity_data)
@@ -869,7 +870,7 @@ class ClientTest(TestCase):
 
     def test_uniqueness_foreign_id(self):
         now = datetime.datetime.now(tzlocal())
-        utcnow = (now - now.utcoffset()).replace(tzinfo=None)
+        utcnow = now.astimezone(pytz.utc)
 
         activity_data = {
             "actor": 1,
@@ -900,7 +901,7 @@ class ClientTest(TestCase):
 
     def test_time_ordering(self):
         """
-        datetime.datetime.utcnow() is our recommended approach
+        datetime.datetime.now(tz=pytz.utc) is our recommended approach
         so if we add an activity
         add one using time
         add another activity it should be in the right spot
@@ -908,7 +909,7 @@ class ClientTest(TestCase):
 
         # timedelta is used to "make sure" that ordering is known even though
         # server time is not
-        custom_time = datetime.datetime.utcnow() - dt.timedelta(days=1)
+        custom_time = datetime.datetime.now(tz=pytz.utc) - dt.timedelta(days=1)
 
         feed = self.user2
         for index, activity_time in enumerate([None, custom_time, None]):
@@ -952,8 +953,8 @@ class ClientTest(TestCase):
 
     def test_serialization(self):
         today = datetime.date.today()
-        then = datetime.datetime.now().replace(microsecond=0)
-        now = datetime.datetime.now()
+        now = datetime.datetime.now(tz=pytz.utc)
+        then = now.replace(microsecond=0)
         data = dict(
             string="string",
             float=0.1,
@@ -1377,6 +1378,13 @@ class ClientTest(TestCase):
         self.assertTrue("updated_at" in user)
         self.assertTrue("id" in user)
 
+    def test_user_get_with_follow_counts(self):
+        response = self.c.users.add(str(uuid1()))
+        user = self.c.users.get(response["id"], with_follow_counts=True)
+        self.assertEqual(user["id"], response["id"])
+        self.assertTrue("followers_count" in user)
+        self.assertTrue("following_count" in user)
+
     def test_user_update(self):
         response = self.c.users.add(str(uuid1()))
         self.c.users.update(response["id"], {"changed": True})
@@ -1473,3 +1481,8 @@ class ClientTest(TestCase):
         reaction.pop("duration")
         enriched_response = f.get(reactions={"counts": True})
         self.assertEqual(enriched_response["results"][0]["reaction_counts"]["like"], 1)
+
+    def test_og(self):
+        response = client.og("https://google.com")
+        self.assertTrue("title" in response)
+        self.assertTrue("description" in response)
